==> insuideindoor-1.0.1%2B1.tar.gz: lib/insuideindoor.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';


void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(

        primarySwatch: Colors.blue,
      ),
      home: const MyHomePageMap(title: 'Flutter Demo Home Page'),
    );
  }
}


 class MyHomePageMap extends StatefulWidget {
  const MyHomePageMap({Key? key, required this.title}) : super(key: key);


  final String title;

  @override
  _MyHomePageMapState createState() => _MyHomePageMapState();
}

class _MyHomePageMapState extends State<MyHomePageMap> {
  final double Lat = 40.41;

  @override
  Widget build(BuildContext context) {

    return Scaffold(

        appBar: new AppBar(title: new Text('Mapbox Map')),
        body: new FlutterMap(
            options: new MapOptions(
                center: new LatLng(41.25981377184681, 28.742446751108982), minZoom: 18.0),

            layers: [
              new TileLayerOptions(
                  urlTemplate:
                  "https://api.mapbox.com/styles/v1/merrill-amm/ckz85ygks000r14qqgptjt1h5/tiles/256/{z}/{x}/{y}@2x?access_token=pk.eyJ1IjoibWVycmlsbC1hbW0iLCJhIjoiY2o4MnM0dm0wNTg5ODJ3bzNiajV1cHF2MyJ9.cLz-hmZiv5NbM4LGt-aBUA",
                  additionalOptions:
              {
                'accesstoken':'pk.eyJ1IjoiaXRzdmljayIsImEiOiJjbDBod3MyOTYwYjJ3M2tubWsxMjA5OGZrIn0.0aAnjwb-_3TkQP8WGkwf-A',
                 //'id' : 'mapbox.mapbox-streets-v8'


              }),
              new MarkerLayerOptions(markers: [
                new Marker(
                    width: 45.0,
                    height: 45.0,
                    point: new LatLng(41.25981377184681, 28.742446751108982),
                    builder: (context) => new Container(
                      child: IconButton(
                        icon: Icon(Icons.location_on),
                        color: Colors.red,
                        iconSize: 45.0,
                        onPressed: () {
                          print('Marker tapped');
                        },
                      ),
                    ))
              ])
            ]));
  }
}

==> insuideindoor-1.0.2%2B1.tar.gz: lib/insuideindoor.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';





void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {

  const MyApp({Key? key}) : super(key: key);


  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(

        primarySwatch: Colors.blue,
      ),
      home: const MyHomePageMap(title: 'MapBox Map',lat : 41.25981377184681 ,lng: 28.742446751108982,),
    );
  }
}


 class MyHomePageMap extends StatefulWidget {
  const MyHomePageMap({Key? key, required this.title, required this.lat, required this.lng}) : super(key: key);


  final String title;
  final double lat ;
  final double lng ;

  @override
  _MyHomePageMapState createState() => _MyHomePageMapState();
}

class _MyHomePageMapState extends State<MyHomePageMap> {
  final double Lat = 40.41;

  @override
  Widget build(BuildContext context) {

    return Scaffold(

        appBar: new AppBar(title: new Text(widget.title)),
        body: new FlutterMap(
            options: new MapOptions(
                center: new LatLng(widget.lat,widget.lng), minZoom: 10.0),

            layers: [
              new TileLayerOptions(
                  urlTemplate:
                  "https://api.mapbox.com/styles/v1/merrill-amm/ckz85ygks000r14qqgptjt1h5/tiles/256/{z}/{x}/{y}@2x?access_token=pk.eyJ1IjoibWVycmlsbC1hbW0iLCJhIjoiY2o4MnM0dm0wNTg5ODJ3bzNiajV1cHF2MyJ9.cLz-hmZiv5NbM4LGt-aBUA",
                  additionalOptions:
              {
                'accesstoken':'pk.eyJ1IjoiaXRzdmljayIsImEiOiJjbDBod3MyOTYwYjJ3M2tubWsxMjA5OGZrIn0.0aAnjwb-_3TkQP8WGkwf-A',
                 //'id' : 'mapbox.mapbox-streets-v8'


              }),
              new MarkerLayerOptions(markers: [
                new Marker(
                    width: 45.0,
                    height: 45.0,
                    point: new LatLng(41.25981377184681, 28.742446751108982),
                    builder: (context) => new Container(
                      child: IconButton(
                        icon: Icon(Icons.location_on),
                        color: Colors.red,
                        iconSize: 45.0,
                        onPressed: () {
                          print('Marker tapped');
                        },
                      ),
                    ))
              ])
            ]));
  }
}
